@@ -29,7 +29,7 @@ our @EXPORT_OK = qw/
 /;
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
-our $VERSION = "v6.26.0";
+our $VERSION = "v6.26.1";
 
 sub op_audit {
     my ($duration_selector) = @_;
@@ -193,34 +193,7 @@ sub op_buffer_count {
 sub op_buffer_time {
     my ($buffer_time_span) = @_;
 
-    return sub {
-        my ($source) = @_;
-
-        return rx_observable->new(sub {
-            my ($subscriber) = @_;
-
-            my @buffer;
-
-            my $si = rx_interval($buffer_time_span)->subscribe(
-                sub {
-                    $subscriber->{next}->([ @buffer ]) if defined $subscriber->{next};
-                    undef @buffer;
-                },
-            );
-
-            my $own_subscriber = {
-                %$subscriber,
-                next => sub {
-                    my ($v) = @_;
-                    push @buffer, $v;
-                },
-            };
-
-            $source->subscribe($own_subscriber);
-
-            return $si;
-        });
-    };
+    return op_buffer(rx_interval($buffer_time_span));
 }
 
 sub _op_catch_error_helper {
